@@ -10,7 +10,7 @@ use strict;
 
 @ISA    = qw(Exporter);
 @EXPORT = ();
-$VERSION= 0.29;
+$VERSION= 0.31;
 
 use Sendmail::M4::Utils;
 
@@ -20,7 +20,7 @@ Sendmail::M4::Mail8 - Stop fake MX and most spammers, sendmail M4 hack file
 
 =head1 STATUS
 
-Version 0.29 (Beta)
+Version 0.31 (Beta)
     
 Now running at B<mail.celmorlauren.com> our own mail server, and has been doing so since 0.23
 
@@ -244,6 +244,55 @@ B<Amendments to release version>
 
 =over 3
 
+=item 03
+
+Oct 2007, the Received: header checking does not work, and currently nothing tried makes it work, fine in test mode. But as headers are not tokenised with sendmail 8.13, can not do anthing usefull with the supplied tools.
+
+So currently does nothing, just returns.
+
+Fix must wait for Sendmail::M4::mail8_daemon and its worker module Sendmail::M4::Mail8_daemon.pm, which will now do more than originally designed to do.
+
+Patch required to remove useless error messages from the logs.
+
+=back
+
+=item 0.30
+
+03 October 2007 CPAN Patch Release
+
+B<Amendments to release version>
+
+=over 3
+
+=item 05
+
+Oct 2007, noted that dots and dashs did not work in From: header checker for names, fixed. However underscores  will still not work
+
+=back
+
+=item 0.31
+
+05 October 2007 CPAN Patch Release
+
+B<Amendments to release version>
+
+=over 3
+
+=item 08 Oct 2007,
+
+Noted that lots of SPAM has Reply-to: yahoo or hotmail, system will now check sendmails standard B<access> database for B<From:####> where #### is system we do not accept mail from. SPAMMERS are now concentrating on finding open-relays or other poorly setup and vunerable systems, many of which seem to be B<Exim> servers. These are of course blocked on their third SPAM or sometimes on their first if they are an open-relay. SPAM detection being done by the second level e-mail system, the CPAN version of the interface between the two systems is currently being re-writen, and we will make it available soon.
+
+=back
+
+=item 0.32
+
+08 October 2007 CPAN Patch Release
+
+B<Amendments to release version>
+
+=over 3
+
+
 =back
 
 =back
@@ -399,6 +448,13 @@ Main items
                         Included as part of the distro, install it
                         to get the full benifits.
 
+    dnl white list      no other way to to let these past
+    Kmail4db hash -o -a.FOUND /etc/mail/mail8/mail4.db
+
+    Standard black list, checked at Reply-to: Header
+    dnl standard black list
+    Kstdaccessdb hash -o -a.FOUND /etc/mail/access.db
+
 =back
 
 =cut
@@ -417,11 +473,16 @@ ECHO
 
     LOCAL_CONFIG;
 
+#some bits that still do not work
+# KCleanToken regex  -s1 ([[:print:]]+)
+# KCleanReceived regex -s1 (\<by\>[[:blank:]]+[[:alnum:]\.]+) 
+
     echo <<ECHO;
 KRlookup dns -RA -a.FOUND -d5s -r4
 KMath arith
-KCleanToken regex  -s1 (.+) 
-KCleanFrom regex  -s1 ([[:alnum:]]+\@[[:alnum:]\.]+) 
+KCleanFrom regex  -s1 ([[:alnum:]_\.\-]+\@[[:alnum:]\.\-]+) 
+KCleanAtHost regex  -s1 (\@[[:alnum:]\.\-]+) 
+KCleanHost regex  -s1 ([[:alnum:]\.\-]+) 
 ECHO
 #mail8_zombie takes care of Zombie names that sendmail can not detect
     if ( -x "/etc/mail/mail8/mail8_zombie" )
@@ -433,13 +494,16 @@ ECHO
     echo <<ECHO;
 dnl white list
 Kmail4db hash -o -a.FOUND /etc/mail/mail8/mail4.db
+dnl standard black list
+Kstdaccessdb hash -o -a.FOUND /etc/mail/access.db
 ECHO
 
 # we can do some checking with HEADER lines
+#HReceived: £>+ScreenHeader
     echo <<ECHO
 
-HReceived: £>+ScreenHeader
 HFrom: £>+ScreenHeader
+HReply-to: £>+ScreenHeader
 
 ECHO
 
@@ -1625,17 +1689,21 @@ GLOBAL A
 TEST SANE(Local_check_relay,Local_check_mail)
 R £*    £: MACRO{ £1
     TEST D({hdr_name}NotReceived) V(NA)
-    TEST D({hdr_name}Received,{currHeader}na by localhost na) V(NA)
-    TEST D({hdr_name}Received,{currHeader}na by your.localhost na) V(NA)
+    TEST D({hdr_name}Received,{currHeader}na by localhost na and "not so much") V(NA)
+    TEST D({hdr_name}Received,{currHeader}na by your.localhost na yack yack end) V(NA)
     R £*            £: £&{hdr_name}
     R Received      £@ MACRO{ £&{currHeader}
         OPTION NOMASH
-        TEST V(anon did not find this,bog standard mailer)
+        TEST D({currHeader}na by www.celmorlauren.com na) V(anon did not find this,bog standard mailer)
         # internal systems should be ok
-        IS FOUND GoodRelay £@ £1
-        R £*                £: £(CleanToken £&{currHeader} £)    
+# does not work, will have to omit untill mail8_daemon can take over this bit of checking
+# as stuff is not tokenised what works in test mode does not work live!
+        R £*                £@ £1
+#IS FOUND GoodRelay £@ £1
+#R £*                £: £(CleanReceived £&{currHeader} £)    
+#R £*    £#error £@ 5.1.1 £: "553 DEBUG " £1
         # external systems must be checked
-        R £+by £+ £+        £: MACRO{ £2 # claiming to be one of our domains?
+        R £* by £+          £: MACRO{ £2 # claiming to be one of our domains?
             OPTION MASH 2
             TEST AUTO(F OUR HELO, V OK HELO)
             dnl localhost is to be expected, most liky as the first server? dnl
@@ -1675,23 +1743,38 @@ RULE
         TEST D({mail_addr}ian, fian\@daisymoo.com, {currHeader}<ian\@daisy.com>) E(Local)
         TEST D({mail_addr}ian\@daisymoo.com, fian\@daisymoo.com, {currHeader}ian\@daisy.com) E(Not Local)
         TEST D({mail_addr}ian, fian\@daisymoo.com, {currHeader}ian\@daisymoo.com) V(NA)
+        TEST D({mail_addr}i.a-n, fi.a-n\@daisy-moo.com, {currHeader}i.a-n\@daisy-moo.com) V(NA)
+        TEST D({mail_addr}i.a_n, fi.a_n\@daisy-moo.com, {currHeader}i.a_n\@daisy-moo.com) V(NA)
         # problem systems such as CPAN Pause, which we want to receive mail from
         IS FOUND BadRelay £@ £1
         R £*            £: £(CleanFrom £&{currHeader} £)    
-        R <£+>          £: £1
-        R £*            £@ MACRO{ £1
-            OPTION MASH 2
-            NOTEST AUTO
-            # if contains From should be ok
-            R £&f       £@ £&{MashSelf}
-            REFUSED
-            # is user external? in which case f & mail_addr will be the same
-            R £*        £: £&{mail_addr}
-            R £&f       £#error £@ 5.1.1 £: "553 SPAM? From: " £&f " claimed to be " £&{MashSelf} " from header line: (From: " £&{currHeader} " )"
-            # internal user, who needs their bottom smacked
-            R £*        £#error £@ 5.1.1 £: "553 SPAM? From: INTERNAL USER! " £&{mail_addr} " claimed to be " £&{MashSelf} " from header line: (From: " £&{currHeader} " )"
-        }MACRO
+        R £*            £: £(SelfMacro {MashTempC} £@ £1 £) £1
+        # if contains From should be ok
+        R £&f       £@ £&{MashTempC}
+        REFUSED
+        # is user external? in which case f & mail_addr will be the same
+        R £*        £: £&{mail_addr}
+        R £&f       £#error £@ 5.1.1 £: "553 SPAM? From: " £&f " claimed to be " £&{MashTempC} " from header line: (From: " £&{currHeader} " )"
+        # internal user, who needs their bottom smacked
+        R £*        £#error £@ 5.1.1 £: "553 SPAM? From: INTERNAL USER! " £&{mail_addr} " claimed to be " £&{MashTempC} " from header line: (From: " £&{currHeader} " )"
     }MACRO
+    R Reply-to     £@ MACRO{ £&{currHeader}
+        OPTION NOMASH
+        NOTEST AUTO
+        # problem systems such as CPAN Pause, which we want to receive mail from
+        IS FOUND BadRelay £@ £1
+        R £*            £: £(CleanFrom £&{currHeader} £)    
+        R £*            £: £(SelfMacro {MashTempC} £@ £1 £) £1
+        R £*            £: From:£1
+        R £*            £: £(stdaccessdb £1 £: £1 £)          standard access database
+        IS THISFOUND AND REFUSED £#error £@ 5.1.1 £: "553 SPAM REFUSED ! From: " £&f " used a Reply-to: address of " £&{MashTempC} " from header line: (Reply-to: " £&{currHeader} " )"
+        R £*            £: £&{MashTempC}
+        R £*            £: £(CleanAtHost £1 £)    
+        R £*            £: £(CleanHost £1 £)    
+        R £*            £: £(SelfMacro {MashTempD} £@ £1 £) £1
+        R £*            £: From:£1
+        R £*            £: £(stdaccessdb £1 £: £1 £)          standard access database
+        IS THISFOUND AND REFUSED £#error £@ 5.1.1 £: "553 SPAM REFUSED ! From: " £&f " used a Reply-to: address of " £&{MashTempD} " from header line: (Reply-to: " £&{currHeader} " )"
 RULE
 
     rule "SScreenHeader", $screen_header,@extra;
